@@ -1,4 +1,5 @@
-from urllib import urlencode, urlopen
+from urllib.parse import urlencode
+from urllib.request import urlopen
 from httplib2 import Http
 
 
@@ -29,7 +30,7 @@ def publish_to_facebook(user, contents):
     token = social_auth.tokens['access_token']
     url = FACEBOOK_API_URL+FACEBOOK_FEED
     data = {
-        "message": unicode(contents).encode('utf-8'),
+        "message": str(contents).encode('utf-8'),
     }
     result = facebook_request(url, token, data=data)
     return result
